@@ -14,19 +14,8 @@ class Save(Modify, Errors):
 
         db = Save.get_db()
 
-        # CUMULATE ERRORS IN ONE SINGLE API ERRORS DURING ADD TIME
-        api_errors = ApiErrors()
-        for entity in entities:
-            with db.session.no_autoflush:
-                entity_api_errors = entity.errors()
-            if entity_api_errors.errors.keys():
-                api_errors.errors.update(entity_api_errors.errors)
-            else:
-                db.session.add(entity)
-
-        # CHECK BEFORE COMMIT
-        if api_errors.errors.keys():
-            raise api_errors
+        # ADD
+        api_errors = Save.add(*entities)
 
         # COMMIT
         try:
